package com.hcloud.microservice.org.facade.client;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.org.facade.fallback.factory.OrgManagerFallbackFactory;
import com.hcloud.microservice.org.facade.forms.BaseOrgAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseOrgForm;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @author xiezt
 */
@FeignClient(value = "org-service" ,path="/org" ,fallbackFactory = OrgManagerFallbackFactory.class)
public interface OrgManagerService {

    /**
     * 查询机构信息（分页查询）
     * @param baseOrgForm
     * @return
     */
    @PostMapping("/searchByPage")
    ResultVO searchOrgInfoByPage(@RequestBody BaseOrgForm baseOrgForm);

    /**
     * 添加机构信息
     * @param baseOrgForm
     * @return
     */
    @PostMapping("/addOrgInfo")
    ResultVO addOrgInfo( @RequestBody BaseOrgForm baseOrgForm);

    /**
     * 更新机构信息
     * @param baseOrgForm
     * @return
     */
    @PostMapping("/updateOrgInfo")
    ResultVO updateOrgInfo(@RequestBody BaseOrgForm baseOrgForm);


    /**
     * 更新机构信息
     * @param guid
     * @return
     */
    @PostMapping("/searchById")
    ResultVO searchOrgInfoById(@RequestParam("guid") String guid);

    /**
     * 分配机构权限
     * @param orgGuid
     * @param list
     * @return
     */
    @PostMapping("/distrOrgAuth")
    ResultVO distributionOrgAuthInfo(@RequestParam("orgGuid") String orgGuid,@RequestBody List<BaseOrgAuthForm> list);

    /**
     * 查询已分配的机构权限
     * @param orgGuid
     * @return
     */
    @GetMapping("/searchOrgAuthInfo")
    ResultVO searchOrgAuthDistributioned(@RequestParam("orgGuid") String orgGuid);
}
