package com.hcloud.microservice.org.facade.fallback.factory;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microservice.org.facade.fallback.OrgMangerFactory;
import com.hcloud.microservice.org.facade.forms.BaseOrgAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseOrgForm;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @author xiezt
 */
@Slf4j
@Component
public class OrgManagerFallbackFactory implements FallbackFactory<OrgMangerFactory> {

    @Override
    public OrgMangerFactory create(Throwable cause) {
        return new OrgMangerFactory() {
            @Override
            public ResultVO searchOrgInfoByPage(BaseOrgForm baseOrgForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            @Override
            public ResultVO addOrgInfo(BaseOrgForm baseOrgForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            @Override
            public ResultVO updateOrgInfo(BaseOrgForm baseOrgForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 更新机构信息
             *
             * @param guid
             * @return
             */
            @Override
            public ResultVO searchOrgInfoById(String guid) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 分配机构权限
             *
             * @param orgGuid
             * @param List
             * @return
             */
            @Override
            public ResultVO distributionOrgAuthInfo(String orgGuid, List<BaseOrgAuthForm> List) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }
            /**
             * 查询已分配的机构权限
             *
             * @param orgGuid
             * @return
             */
            @Override
            public ResultVO searchOrgAuthDistributioned(String orgGuid) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }
        };
    }
}
